function h=makeFig(n,flags)
% makeFig <make Figure n>
% Usage:: h=makeFigFig(n,flags)
%

% revision history:
% 02/08/21 Mark D. Shattuck <mds> makeFig.m
% 02/09/20 mds SPDensity.m
% 02/14/20 mds Example.m
% 02/22/20 mds SPVib.m

%% Parse Input
if(~exist('flags','var') || isempty(flags))
  flags=false;
end

%% Main
switch n
  case 0 % make any static images
    clf;
    h={'photogate.jpg','photogate_schem.png','photogate_bb.png',...
      '330ohm.png','100ohm.png','1K.png'...
      'Rpzoom.jpg','cantilever.jpg','pluck.jpg'...
      'shadow.jpg'};
    if(~exist(h{1},'file') || flags) % photogate
      im=double(permute(imread('IMG_1910.JPG'),[1 2 3]))/256;
      imwrite(im,h{1})
    end
    if(~exist(h{2},'file')) % photogate_scheme
      exe='C:\Downloads\Installed\fritzing.0.9.3b.64.pc\Fritzing.exe';
      system(sprintf('%s photogate.fzz',exe));
    end
    if(~exist(h{3},'file')) % lightgate_bb
      exe='C:\Downloads\Installed\fritzing.0.9.3b.64.pc\Fritzing.exe';
      system(sprintf('%s photogate.fzz',exe));
    end
    if(~exist(h{4},'file') || flags) % 300ohm
      im=double(permute(imread('IMG_1932.JPG'),[2 1 3]))/256;
      imwrite(im(2080:2240,1300:1840,:).^1.2,h{4})
    end
    if(~exist(h{5},'file') || flags) % 100ohm
      im=double(permute(imread('IMG_1939.JPG'),[2 1 3]))/256;
      imwrite(im(2030+(0:160),1350+(0:540),:).^1.2,h{5})
    end
    if(~exist(h{6},'file') || flags) % 1K
      im=double(permute(imread('IMG_1939.JPG'),[2 1 3]))/256;
      imwrite(im(1750+(0:160),1350+(0:540),:).^1.2,h{6})
    end
    if(~exist(h{7},'file') || flags) % Rpzoom
      im=double(permute(imread('IMG_1923.JPG'),[1 2 3]))/256;
      imwrite(im(500:3000,1800:4000,:).^.8,h{7})
    end
    if(~exist(h{8},'file') || flags) % cantilever
      im=double(permute(imread('IMG_1942.JPG'),[1 2 3]))/256;
      imr=clip(imrotate(im,-.8,'bicubic'),0,1);
      fig=figure('Position',[1 1 1000 500]);
      simage(imr(1300:1900,200:3800,:).^.7); 
      hold on; 
      x=170:1775;
      yc=250;
      plot(x,0*x+yc,'k',...
           x([1 1]),yc+50*[-1 1],'k',...
           x([end end]),yc+50*[-1 1],'k',...
           'linewidth',2); 
      text(mean(x),yc-120,'Length','fontsize',25,'horiz','center');
      drawnow;
      im1=getframe();
      imwrite(im1.cdata,h{8});
      hold off
      close(fig);
    end
    if(~exist(h{9},'file') || flags) % pluck
      im=double(permute(imread('IMG_1912.JPG'),[1 2 3]))/256;
      imwrite(im,h{9});
    end
    if(~exist(h{10},'file') || flags) % shadow
      im=double(permute(imread('IMG_1945.JPG'),[1 2 3]))/256;
      imwrite(im(1200:1600,(2000:3000),:).^3,h{10});
    end

  case 1
    V=load('manual.txt');
    h=plot((0:767)*V(end)/768/1e6,V(1:end-1));
    set(gca,'fontsize',20)
    axis([0 3 660 740])
    xlabel('Time (s)');
    ylabel('Counts')
  otherwise
    h=-1;
end

